<?php
namespace Teknisa\CADCTB\Services;

use Teknisa\CADCTB\Factories\Ger06300CentroDeCustofactory;
use Teknisa\Model\Geral\Entities\Filial;
use Teknisa\Libs\Util\Environment;

class Ger06300CentroDeCustoService {

	protected $environment;
	protected $entityManager;
	protected $ger06300CentroDeCustofactory; 

	public function __construct(Environment $environment, \Doctrine\ORM\EntityManager $entityManager, Ger06300CentroDeCustofactory $ger06300CentroDeCustofactory) {
		$this->environment = $environment;
		$this->entityManager = $entityManager;
		$this->ger06300CentroDeCustofactory = $ger06300CentroDeCustofactory;
	}

	public function validatePadraoOnDelete($row) {
		if ($row["CENTCUSTPADRAO"] == "S") {
			$this->entityManager->beginTransaction();
			try {
				$paransFilial = array(
                	'nrorg'    => $this->environment->getNrOrgTrab(),
                    'cdfilial' => $row["CDFILIAL"]
                );
				$filial = $this->ger06300CentroDeCustofactory->getFilial($paransFilial);
				$filial->setCdcentcust(null);
				$filial->persist();
				$this->entityManager->flush();
				$this->entityManager->commit();
			} catch (\Exception $e) {
				$this->entityManager->rollback();
				throw new \Exception("Erro ao validar Centro de Custo Padrão!", 500);
			}
		}
	}

	public function validatePadraoOnSave($row) {
		if ($row["CENTCUSTPADRAO"] == "S") {
			$this->entityManager->beginTransaction();
			try {
				$paransFilial = array(
                	'nrorg'    => $this->environment->getNrOrgTrab(),
                    'cdfilial' => $row["CDFILIAL"]
                );
				$filial = $this->ger06300CentroDeCustofactory->getFilial($paransFilial);
				$filial->setCdcentcust($row["CDCENTCUST"]);
				$this->entityManager->persist($filial);
				$this->entityManager->flush();
				$this->entityManager->commit();
			} catch (\Exception $e) {
				$this->entityManager->rollback();
				throw new \Exception("Erro ao validar Centro de Custo Padrão!", 500);
			}
		}
	}
	
	public function cadastroAutomaticoCentroCusto($row) {
    try{
      $arrayFilial = $row["CDCENTCUST"];
      
      foreach($arrayFilial as $filial){
          $rowToSave = $row;
          $rowToSave['CDCENTCUST'] = $filial;
          if($row['IDOPERACAO'] === 'I'){
            $this->saveFilial($rowToSave);
          } 
          else if($row['IDOPERACAO'] === 'S'){
            $this->deleteFilial($row);
          }
      }
      
      foreach($arrayFilial as $filial){
          $rowToSave = $row;
          $rowToSave['CDCENTCUST'] = $filial;
          if($row['IDOPERACAO'] === 'S'){
            $this->saveFilial($rowToSave);
          }
      }
      
    } catch(\Exception $e) {
        throw $e;
    }
    
	}
	
	public function saveFilial($row) {
    try{
      $arrayFilial = $row["CDFILIAL"];
      $nrorg = $row['NRORG'];
      $operador = $row['CDOPERADOR']; 
      $i = 0;
      foreach($arrayFilial as $cdfilial){
          $selectFilial = $this->ger06300CentroDeCustofactory->selectEmpresa($cdfilial, $row['CDCENTCUST']);
          if(empty($selectFilial)){
            $params = array(
              "CDFILIAL"       => $cdfilial,
              "CDOPERINCLUSAO"  => $operador,
              "CDOPERULTATU"    => $operador,
              "CDCENTCUST"     => $row['CDCENTCUST'],
              "DTINCLUSAO"      => $row['DATA'],
              "DTULTATU"        => $row['DATA'],
              "IDATIVO"         => 'S',
              "NRORG"           => $nrorg,
              "NRORGINCLUSAO"   => $nrorg,
              "NRORGULTATU"     => $nrorg
            );
            $i++;
            
            $this->ger06300CentroDeCustofactory->saveFilial($params);
          }
      }
      
    } catch(\Exception $e) {
        throw $e;
    }
    
    }
    
    public function deleteFilial($row) {
    try{
      $arrayFilial = $row["CDFILIAL"];
      $atual = "";
      foreach($arrayFilial as $cdfilial){
          $atual = $cdfilial;
          
          $this->ger06300CentroDeCustofactory->deleteFilial($atual);
      }
    } catch(\Exception $e) {
        throw $e;
    }
    
    }
}